@@ -1,6 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
- * Copyright (C) 2012-2016 Matthias Klumpp <matthias@tenstral.net>
+ * Copyright (C) 2012-2021 Matthias Klumpp <matthias@tenstral.net>
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -25,15 +25,25 @@
 
 G_BEGIN_DECLS
 
-gboolean		ascli_validate_file (gchar *fname,
-						gboolean pedantic);
-
 gint			ascli_validate_files (gchar **argv,
 						gint argc,
-						gboolean pedantic);
+						gboolean explain,
+						gboolean pedantic,
+						gboolean use_net);
+gint			ascli_validate_files_format (gchar **argv,
+							gint argc,
+							const gchar *format,
+							gboolean use_net);
 
 gint			ascli_validate_tree (const gchar *root_dir,
-						gboolean pedantic);
+						gboolean explain,
+						gboolean pedantic,
+						gboolean use_net);
+gint			ascli_validate_tree_format (const gchar *root_dir,
+						    const gchar *format,
+						    gboolean use_net);
+
+gint			ascli_check_license (const gchar *license);
 
 G_END_DECLS
 
